@@ -3,7 +3,6 @@ from pathlib import Path
 from typing import TYPE_CHECKING, Dict, Optional, Tuple
 
 import fsspec
-import zarr
 from datatree import DataTree
 
 # fmt: off
@@ -16,15 +15,9 @@ if TYPE_CHECKING:
 # fmt: on
 from ..echodata.echodata import XARRAY_ENGINE_MAP, EchoData
 from ..utils import io
+from ..utils.coding import COMPRESSION_SETTINGS
 from ..utils.log import _init_logger
 
-COMPRESSION_SETTINGS = {
-    "netcdf4": {"zlib": True, "complevel": 4},
-    "zarr": {"compressor": zarr.Blosc(cname="zstd", clevel=3, shuffle=2)},
-}
-
-DEFAULT_CHUNK_SIZE = {"range_sample": 25000, "ping_time": 2500}
-
 BEAM_SUBGROUP_DEFAULT = "Beam_group1"
 
 # Logging setup
@@ -104,30 +97,26 @@ def to_file(
 def _save_groups_to_file(echodata, output_path, engine, compress=True):
     """Serialize all groups to file."""
     # TODO: in terms of chunking, would using rechunker at the end be faster and more convenient?
+    # TODO: investigate chunking before we save Dataset to a file
 
     # Top-level group
-    io.save_file(echodata["Top-level"], path=output_path, mode="w", engine=engine)
+    io.save_file(
+        echodata["Top-level"],
+        path=output_path,
+        mode="w",
+        engine=engine,
+        compression_settings=COMPRESSION_SETTINGS[engine] if compress else None,
+    )
 
     # Environment group
-    if "time1" in echodata["Environment"]:
-        io.save_file(
-            # echodata["Environment"].chunk(
-            #     {"time1": DEFAULT_CHUNK_SIZE["ping_time"]}
-            # ),  # TODO: chunking necessary?
-            echodata["Environment"],
-            path=output_path,
-            mode="a",
-            engine=engine,
-            group="Environment",
-        )
-    else:
-        io.save_file(
-            echodata["Environment"],
-            path=output_path,
-            mode="a",
-            engine=engine,
-            group="Environment",
-        )
+    io.save_file(
+        echodata["Environment"],  # TODO: chunking necessary?
+        path=output_path,
+        mode="a",
+        engine=engine,
+        group="Environment",
+        compression_settings=COMPRESSION_SETTINGS[engine] if compress else None,
+    )
 
     # Platform group
     io.save_file(
@@ -157,6 +146,7 @@ def _save_groups_to_file(echodata, output_path, engine, compress=True):
         group="Provenance",
         mode="a",
         engine=engine,
+        compression_settings=COMPRESSION_SETTINGS[engine] if compress else None,
     )
 
     # Sonar group
@@ -166,17 +156,13 @@ def _save_groups_to_file(echodata, output_path, engine, compress=True):
         group="Sonar",
         mode="a",
         engine=engine,
+        compression_settings=COMPRESSION_SETTINGS[engine] if compress else None,
     )
 
     # /Sonar/Beam_groupX group
     if echodata.sonar_model == "AD2CP":
         for i in range(1, len(echodata["Sonar"]["beam_group"]) + 1):
             io.save_file(
-                # echodata[f"Sonar/Beam_group{i}"].chunk(
-                #     {
-                #         "ping_time": DEFAULT_CHUNK_SIZE["ping_time"],
-                #     }
-                # ),
                 echodata[f"Sonar/Beam_group{i}"],
                 path=output_path,
                 mode="a",
@@ -186,12 +172,6 @@ def _save_groups_to_file(echodata, output_path, engine, compress=True):
             )
     else:
         io.save_file(
-            # echodata[f"Sonar/{BEAM_SUBGROUP_DEFAULT}"].chunk(
-            #     {
-            #         "range_sample": DEFAULT_CHUNK_SIZE["range_sample"],
-            #         "ping_time": DEFAULT_CHUNK_SIZE["ping_time"],
-            #     }
-            # ),
             echodata[f"Sonar/{BEAM_SUBGROUP_DEFAULT}"],
             path=output_path,
             mode="a",
@@ -202,12 +182,6 @@ def _save_groups_to_file(echodata, output_path, engine, compress=True):
         if echodata["Sonar/Beam_group2"] is not None:
             # some sonar model does not produce Sonar/Beam_group2
             io.save_file(
-                # echodata["Sonar/Beam_group2"].chunk(
-                #     {
-                #         "range_sample": DEFAULT_CHUNK_SIZE["range_sample"],
-                #         "ping_time": DEFAULT_CHUNK_SIZE["ping_time"],
-                #     }
-                # ),
                 echodata["Sonar/Beam_group2"],
                 path=output_path,
                 mode="a",
@@ -217,27 +191,14 @@ def _save_groups_to_file(echodata, output_path, engine, compress=True):
             )
 
     # Vendor_specific group
-    if "ping_time" in echodata["Vendor_specific"]:
-        io.save_file(
-            # echodata["Vendor_specific"].chunk(
-            #     {"ping_time": DEFAULT_CHUNK_SIZE["ping_time"]}
-            # ),  # TODO: chunking necessary?
-            echodata["Vendor_specific"],
-            path=output_path,
-            mode="a",
-            engine=engine,
-            group="Vendor_specific",
-            compression_settings=COMPRESSION_SETTINGS[engine] if compress else None,
-        )
-    else:
-        io.save_file(
-            echodata["Vendor_specific"],  # TODO: chunking necessary?
-            path=output_path,
-            mode="a",
-            engine=engine,
-            group="Vendor_specific",
-            compression_settings=COMPRESSION_SETTINGS[engine] if compress else None,
-        )
+    io.save_file(
+        echodata["Vendor_specific"],  # TODO: chunking necessary?
+        path=output_path,
+        mode="a",
+        engine=engine,
+        group="Vendor_specific",
+        compression_settings=COMPRESSION_SETTINGS[engine] if compress else None,
+    )
 
 
 def _set_convert_params(param_dict: Dict[str, str]) -> Dict[str, str]:
@@ -368,7 +329,8 @@ def open_raw(
         options for cloud storage
     offload_to_zarr: bool
         If True, variables with a large memory footprint will be
-        written to a temporary zarr store.
+        written to a temporary zarr store called ``temp_echopype_output/parsed2zarr_temp_files``
+        under the current execution folder
     max_zarr_mb : int
         maximum MB that each zarr chunk should hold, when offloading
         variables with a large memory footprint to a temporary zarr store
@@ -463,33 +425,35 @@ def open_raw(
 
     parser.parse_raw()
 
-    # code block corresponding to directly writing parsed data to zarr
-    if offload_to_zarr and (sonar_model in ["EK60", "ES70", "EK80", "ES80", "EA640"]):
+    # Direct offload to zarr and rectangularization only available for some sonar models
+    if sonar_model in ["EK60", "ES70", "EK80", "ES80", "EA640"]:
 
-        # Determines if writing to zarr is necessary and writes to zarr
+        # Create sonar_model-specific p2z object
         p2z = SONAR_MODELS[sonar_model]["parsed2zarr"](parser)
 
-        # TODO: perform more robust tests for the 'auto' heuristic value
-        if offload_to_zarr == "auto" and p2z.write_to_zarr(mem_mult=0.4):
-            p2z.datagram_to_zarr(max_mb=max_zarr_mb)
-        elif offload_to_zarr is True:
+        # Determines if writing to zarr is necessary and writes to zarr
+        p2z_flag = offload_to_zarr is True or (
+            offload_to_zarr == "auto" and p2z.whether_write_to_zarr(mem_mult=0.4)
+        )
+
+        if p2z_flag:
             p2z.datagram_to_zarr(max_mb=max_zarr_mb)
+            # Rectangularize the transmit data
+            parser.rectangularize_transmit_ping_data(data_type="complex")
         else:
             del p2z
+            # Create general p2z object
             p2z = Parsed2Zarr(parser)
-            if "ALL" in parser.data_type:
-                parser.rectangularize_data()
+            parser.rectangularize_data()
 
     else:
-        p2z = Parsed2Zarr(parser)
-        if (sonar_model in ["EK60", "ES70", "EK80", "ES80", "EA640"]) and (
-            "ALL" in parser.data_type
-        ):
-            parser.rectangularize_data()
+        # No rectangularization for other sonar models
+        p2z = Parsed2Zarr(parser)  # Create general p2z object
 
     setgrouper = SONAR_MODELS[sonar_model]["set_groups"](
         parser,
         input_file=file_chk,
+        xml_path=xml_chk,
         output_path=None,
         sonar_model=sonar_model,
         params=_set_convert_params(convert_params),
