@@ -219,13 +219,8 @@ class NoMorePackets(Exception):
 
 
 class ParseAd2cp(ParseBase):
-    def __init__(
-        self,
-        *args,
-        params,
-        **kwargs,
-    ):
-        super().__init__(*args, **kwargs)
+    def __init__(self, file, params, storage_options={}, dgram_zarr_vars={}):
+        super().__init__(file, storage_options)
         self.config = None
         self.packets: List[Ad2cpDataPacket] = []
 
