@@ -4,12 +4,12 @@ from typing import List
 import numpy as np
 import xarray as xr
 
-from ..utils.coding import set_encodings
+from ..utils.coding import set_time_encodings
 from ..utils.log import _init_logger
 from ..utils.prov import echopype_prov_attrs, source_files_vars
 
 # fmt: off
-from .set_groups_base import DEFAULT_CHUNK_SIZE, SetGroupsBase
+from .set_groups_base import SetGroupsBase
 
 # fmt: on
 
@@ -59,8 +59,29 @@ class SetGroupsEK60(SetGroupsBase):
         super().__init__(*args, **kwargs)
 
         self.old_ping_time = None
+
+        # obtain sorted channel dict in ascending order
+        channels = list(self.parser_obj.config_datagram["transceivers"].keys())
+        channel_ids = {
+            ch: self.parser_obj.config_datagram["transceivers"][ch]["channel_id"] for ch in channels
+        }
+        # example sorted_channel from a 5-channel data file for future reference:
+        # 1: 'GPT  18 kHz 009072034d45 1-1 ES18-11'
+        # 2: 'GPT  38 kHz 009072033fa2 2-1 ES38B'
+        # 3: 'GPT  70 kHz 009072058c6c 3-1 ES70-7C'
+        # 4: 'GPT 120 kHz 00907205794e 4-1 ES120-7C'
+        # 5: 'GPT 200 kHz 0090720346a8 5-1 ES200-7C'
+        # In some examples the channels may not be ordered, thus sorting is required
+        self.sorted_channel = dict(sorted(channel_ids.items(), key=lambda item: item[1]))
+
+        # obtain corresponding frequency dict from sorted channels
+        self.freq = [
+            self.parser_obj.config_datagram["transceivers"][ch]["frequency"]
+            for ch in self.sorted_channel.keys()
+        ]
+
         # correct duplicate ping_time
-        for ch in self.parser_obj.config_datagram["transceivers"].keys():
+        for ch in self.sorted_channel.keys():
             ping_time = self.parser_obj.ping_time[ch]
             _, unique_idx = np.unique(ping_time, return_index=True)
             duplicates = np.invert(np.isin(np.arange(len(ping_time)), unique_idx))
@@ -111,26 +132,24 @@ class SetGroupsEK60(SetGroupsBase):
         """Set the Provenance group."""
         prov_dict = echopype_prov_attrs(process_type="conversion")
         prov_dict["duplicate_ping_times"] = 1 if self.old_ping_time is not None else 0
-        source_files = source_files_vars(self.input_file)
+        files_vars = source_files_vars(self.input_file)
         if self.old_ping_time is not None:
-            ds = xr.Dataset(
-                data_vars={
-                    "old_ping_time": self.old_ping_time,
-                    **source_files,
-                }
-            )
+            source_vars = {"old_ping_time": self.old_ping_time, **files_vars["source_files_var"]}
         else:
-            ds = xr.Dataset(data_vars=source_files)
-        ds = ds.assign_attrs(prov_dict)
+            source_vars = files_vars["source_files_var"]
+
+        ds = xr.Dataset(
+            data_vars=source_vars, coords=files_vars["source_files_coord"], attrs=prov_dict
+        )
+
         return ds
 
     def set_env(self) -> xr.Dataset:
         """Set the Environment group."""
-        ch_ids = list(self.parser_obj.config_datagram["transceivers"].keys())
-        ds_env = []
 
         # Loop over channels
-        for ch in ch_ids:
+        ds_env = []
+        for ch in self.sorted_channel.keys():
             ds_tmp = xr.Dataset(
                 {
                     "absorption_indicative": (
@@ -167,9 +186,7 @@ class SetGroupsEK60(SetGroupsBase):
                 },
             )
             # Attach channel dimension/coordinate
-            ds_tmp = ds_tmp.expand_dims(
-                {"channel": [self.parser_obj.config_datagram["transceivers"][ch]["channel_id"]]}
-            )
+            ds_tmp = ds_tmp.expand_dims({"channel": [self.sorted_channel[ch]]})
             ds_tmp["channel"] = ds_tmp["channel"].assign_attrs(
                 self._varattrs["beam_coord_default"]["channel"]
             )
@@ -190,7 +207,7 @@ class SetGroupsEK60(SetGroupsBase):
         # Merge data from all channels
         ds = xr.merge(ds_env)
 
-        return set_encodings(ds)
+        return set_time_encodings(ds)
 
     def set_sonar(self) -> xr.Dataset:
         """Set the Sonar group."""
@@ -216,7 +233,7 @@ class SetGroupsEK60(SetGroupsBase):
 
         return ds
 
-    def set_platform(self, NMEA_only=False) -> xr.Dataset:
+    def set_platform(self) -> xr.Dataset:
         """Set the Platform group."""
 
         # Collect variables
@@ -249,144 +266,130 @@ class SetGroupsEK60(SetGroupsBase):
                 )
             },
         )
-        ds = ds.chunk({"time1": DEFAULT_CHUNK_SIZE["ping_time"]})
 
-        if not NMEA_only:
-            ch_ids = list(self.parser_obj.config_datagram["transceivers"].keys())
+        # TODO: consider allow users to set water_level like in EK80?
+        # if self.ui_param['water_level'] is not None:
+        #     water_level = self.ui_param['water_level']
+        # else:
+        #     water_level = np.nan
+        #     print('WARNING: The water_level_draft was not in the file. Value '
+        #           'set to None.')
 
-            # TODO: consider allow users to set water_level like in EK80?
-            # if self.ui_param['water_level'] is not None:
-            #     water_level = self.ui_param['water_level']
-            # else:
-            #     water_level = np.nan
-            #     print('WARNING: The water_level_draft was not in the file. Value '
-            #           'set to None.')
-
-            # Loop over channels and merge all
-            ds_plat = []
-            for ch in ch_ids:
-                ds_tmp = xr.Dataset(
-                    {
-                        "pitch": (
-                            ["time2"],
-                            self.parser_obj.ping_data_dict["pitch"][ch],
-                            self._varattrs["platform_var_default"]["pitch"],
-                        ),
-                        "roll": (
-                            ["time2"],
-                            self.parser_obj.ping_data_dict["roll"][ch],
-                            self._varattrs["platform_var_default"]["roll"],
-                        ),
-                        "vertical_offset": (
-                            ["time2"],
-                            self.parser_obj.ping_data_dict["heave"][ch],
-                            self._varattrs["platform_var_default"]["vertical_offset"],
-                        ),
-                        "water_level": (
-                            ["time3"],
-                            self.parser_obj.ping_data_dict["transducer_depth"][ch],
-                            self._varattrs["platform_var_default"]["water_level"],
-                        ),
-                        "transducer_offset_x": (
-                            [],
-                            self.parser_obj.config_datagram["transceivers"][ch].get(
-                                "pos_x", np.nan
-                            ),
-                            self._varattrs["platform_var_default"]["transducer_offset_x"],
-                        ),
-                        "transducer_offset_y": (
-                            [],
-                            self.parser_obj.config_datagram["transceivers"][ch].get(
-                                "pos_y", np.nan
-                            ),
-                            self._varattrs["platform_var_default"]["transducer_offset_y"],
-                        ),
-                        "transducer_offset_z": (
-                            [],
-                            self.parser_obj.config_datagram["transceivers"][ch].get(
-                                "pos_z", np.nan
-                            ),
-                            self._varattrs["platform_var_default"]["transducer_offset_z"],
-                        ),
-                        **{
-                            var: ([], np.nan, self._varattrs["platform_var_default"][var])
-                            for var in [
-                                "MRU_offset_x",
-                                "MRU_offset_y",
-                                "MRU_offset_z",
-                                "MRU_rotation_x",
-                                "MRU_rotation_y",
-                                "MRU_rotation_z",
-                                "position_offset_x",
-                                "position_offset_y",
-                                "position_offset_z",
-                            ]
+        # Loop over channels and merge all
+        ds_plat = []
+        for ch in self.sorted_channel.keys():
+            ds_tmp = xr.Dataset(
+                {
+                    "pitch": (
+                        ["time2"],
+                        self.parser_obj.ping_data_dict["pitch"][ch],
+                        self._varattrs["platform_var_default"]["pitch"],
+                    ),
+                    "roll": (
+                        ["time2"],
+                        self.parser_obj.ping_data_dict["roll"][ch],
+                        self._varattrs["platform_var_default"]["roll"],
+                    ),
+                    "vertical_offset": (
+                        ["time2"],
+                        self.parser_obj.ping_data_dict["heave"][ch],
+                        self._varattrs["platform_var_default"]["vertical_offset"],
+                    ),
+                    "water_level": (
+                        ["time3"],
+                        self.parser_obj.ping_data_dict["transducer_depth"][ch],
+                        self._varattrs["platform_var_default"]["water_level"],
+                    ),
+                    "transducer_offset_x": (
+                        [],
+                        self.parser_obj.config_datagram["transceivers"][ch].get("pos_x", np.nan),
+                        self._varattrs["platform_var_default"]["transducer_offset_x"],
+                    ),
+                    "transducer_offset_y": (
+                        [],
+                        self.parser_obj.config_datagram["transceivers"][ch].get("pos_y", np.nan),
+                        self._varattrs["platform_var_default"]["transducer_offset_y"],
+                    ),
+                    "transducer_offset_z": (
+                        [],
+                        self.parser_obj.config_datagram["transceivers"][ch].get("pos_z", np.nan),
+                        self._varattrs["platform_var_default"]["transducer_offset_z"],
+                    ),
+                    **{
+                        var: ([], np.nan, self._varattrs["platform_var_default"][var])
+                        for var in [
+                            "MRU_offset_x",
+                            "MRU_offset_y",
+                            "MRU_offset_z",
+                            "MRU_rotation_x",
+                            "MRU_rotation_y",
+                            "MRU_rotation_z",
+                            "position_offset_x",
+                            "position_offset_y",
+                            "position_offset_z",
+                        ]
+                    },
+                },
+                coords={
+                    "time2": (
+                        ["time2"],
+                        self.parser_obj.ping_time[ch],
+                        {
+                            "axis": "T",
+                            "long_name": "Timestamps for platform motion and orientation data",
+                            "standard_name": "time",
+                            "comment": "Time coordinate corresponding to platform motion and "
+                            "orientation data.",
                         },
-                    },
-                    coords={
-                        "time2": (
-                            ["time2"],
-                            self.parser_obj.ping_time[ch],
-                            {
-                                "axis": "T",
-                                "long_name": "Timestamps for platform motion and orientation data",
-                                "standard_name": "time",
-                                "comment": "Time coordinate corresponding to platform motion and "
-                                "orientation data.",
-                            },
-                        ),
-                        "time3": (
-                            ["time3"],
-                            self.parser_obj.ping_time[ch],
-                            {
-                                "axis": "T",
-                                "long_name": "Timestamps for platform-related sampling environment",
-                                "standard_name": "time",
-                                "comment": "Time coordinate corresponding to platform-related "
-                                "sampling environment.",
-                            },
-                        ),
-                    },
-                    attrs={
-                        "platform_code_ICES": self.ui_param["platform_code_ICES"],
-                        "platform_name": self.ui_param["platform_name"],
-                        "platform_type": self.ui_param["platform_type"],
-                    },
-                )
+                    ),
+                    "time3": (
+                        ["time3"],
+                        self.parser_obj.ping_time[ch],
+                        {
+                            "axis": "T",
+                            "long_name": "Timestamps for platform-related sampling environment",
+                            "standard_name": "time",
+                            "comment": "Time coordinate corresponding to platform-related "
+                            "sampling environment.",
+                        },
+                    ),
+                },
+                attrs={
+                    "platform_code_ICES": self.ui_param["platform_code_ICES"],
+                    "platform_name": self.ui_param["platform_name"],
+                    "platform_type": self.ui_param["platform_type"],
+                },
+            )
 
-                # Attach channel dimension/coordinate
-                ds_tmp = ds_tmp.expand_dims(
-                    {"channel": [self.parser_obj.config_datagram["transceivers"][ch]["channel_id"]]}
-                )
-                ds_tmp["channel"] = ds_tmp["channel"].assign_attrs(
-                    self._varattrs["beam_coord_default"]["channel"]
-                )
+            # Attach channel dimension/coordinate
+            ds_tmp = ds_tmp.expand_dims({"channel": [self.sorted_channel[ch]]})
+            ds_tmp["channel"] = ds_tmp["channel"].assign_attrs(
+                self._varattrs["beam_coord_default"]["channel"]
+            )
 
-                ds_tmp["frequency_nominal"] = (
-                    ["channel"],
-                    [self.parser_obj.config_datagram["transceivers"][ch]["frequency"]],
-                    {
-                        "units": "Hz",
-                        "long_name": "Transducer frequency",
-                        "valid_min": 0.0,
-                        "standard_name": "sound_frequency",
-                    },
-                )
+            ds_tmp["frequency_nominal"] = (
+                ["channel"],
+                [self.parser_obj.config_datagram["transceivers"][ch]["frequency"]],
+                {
+                    "units": "Hz",
+                    "long_name": "Transducer frequency",
+                    "valid_min": 0.0,
+                    "standard_name": "sound_frequency",
+                },
+            )
 
-                ds_plat.append(ds_tmp)
+            ds_plat.append(ds_tmp)
 
-            # Merge data from all channels
-            # TODO: for current test data we see all
-            #  pitch/roll/heave are the same for all freq channels
-            #  consider only saving those from the first channel
-            ds_plat = xr.merge(ds_plat)
+        # Merge data from all channels
+        # TODO: for current test data we see all
+        #  pitch/roll/heave are the same for all freq channels
+        #  consider only saving those from the first channel
+        ds_plat = xr.merge(ds_plat)
 
-            # Merge with NMEA data
-            ds = xr.merge([ds, ds_plat], combine_attrs="override")
+        # Merge with NMEA data
+        ds = xr.merge([ds, ds_plat], combine_attrs="override")
 
-            ds = ds.chunk({"time2": DEFAULT_CHUNK_SIZE["ping_time"]})
-
-        return set_encodings(ds)
+        return set_time_encodings(ds)
 
     def _set_beam_group1_zarr_vars(self, ds: xr.Dataset) -> xr.Dataset:
         """
@@ -426,15 +429,9 @@ class SetGroupsEK60(SetGroupsBase):
 
     def set_beam(self) -> List[xr.Dataset]:
         """Set the /Sonar/Beam_group1 group."""
-        # Get channel keys and frequency
-        ch_ids = list(self.parser_obj.config_datagram["transceivers"].keys())
-        freq = np.array(
-            [v["frequency"] for v in self.parser_obj.config_datagram["transceivers"].values()]
-        )
 
         # Channel-specific variables
         params = [
-            "channel_id",
             "beam_type",
             "beamwidth_alongship",
             "beamwidth_athwartship",
@@ -456,7 +453,7 @@ class SetGroupsEK60(SetGroupsBase):
         for param in params:
             beam_params[param] = [
                 self.parser_obj.config_datagram["transceivers"][ch_seq].get(param, np.nan)
-                for ch_seq in ch_ids
+                for ch_seq in self.sorted_channel.keys()
             ]
 
         # TODO: Need to discuss if to remove INDEX2POWER factor from the backscatter_r
@@ -469,7 +466,7 @@ class SetGroupsEK60(SetGroupsBase):
             {
                 "frequency_nominal": (
                     ["channel"],
-                    freq,
+                    self.freq,
                     {
                         "units": "Hz",
                         "long_name": "Transducer frequency",
@@ -609,7 +606,7 @@ class SetGroupsEK60(SetGroupsBase):
             coords={
                 "channel": (
                     ["channel"],
-                    beam_params["channel_id"],
+                    list(self.sorted_channel.values()),
                     self._varattrs["beam_coord_default"]["channel"],
                 ),
             },
@@ -618,7 +615,7 @@ class SetGroupsEK60(SetGroupsBase):
 
         # Construct Dataset with ping-by-ping data from all channels
         ds_backscatter = []
-        for ch in ch_ids:
+        for ch in self.sorted_channel.keys():
 
             var_dict = {
                 "sample_interval": (
@@ -750,9 +747,7 @@ class SetGroupsEK60(SetGroupsBase):
                     )
 
             # Attach frequency dimension/coordinate
-            ds_tmp = ds_tmp.expand_dims(
-                {"channel": [self.parser_obj.config_datagram["transceivers"][ch]["channel_id"]]}
-            )
+            ds_tmp = ds_tmp.expand_dims({"channel": [self.sorted_channel[ch]]})
             ds_tmp["channel"] = ds_tmp["channel"].assign_attrs(
                 self._varattrs["beam_coord_default"]["channel"]
             )
@@ -771,26 +766,36 @@ class SetGroupsEK60(SetGroupsBase):
             ds, self.beam_only_names, self.beam_ping_time_names, self.ping_time_only_names
         )
 
-        return [set_encodings(ds)]
+        return [set_time_encodings(ds)]
 
     def set_vendor(self) -> xr.Dataset:
-        # Retrieve pulse length and sa correction
-        config = self.parser_obj.config_datagram["transceivers"]
-        freq = [v["frequency"] for v in config.values()]
-        ch_ids = list(self.parser_obj.config_datagram["transceivers"].keys())
-        channel = [
-            self.parser_obj.config_datagram["transceivers"][ch_seq].get("channel_id", np.nan)
-            for ch_seq in ch_ids
+
+        # Retrieve pulse length, gain, and sa correction
+        pulse_length = np.array(
+            [
+                self.parser_obj.config_datagram["transceivers"][ch]["pulse_length_table"]
+                for ch in self.sorted_channel.keys()
+            ]
+        )
+
+        gain = np.array(
+            [
+                self.parser_obj.config_datagram["transceivers"][ch]["gain_table"]
+                for ch in self.sorted_channel.keys()
+            ]
+        )
+
+        sa_correction = [
+            self.parser_obj.config_datagram["transceivers"][ch]["sa_correction_table"]
+            for ch in self.sorted_channel.keys()
         ]
-        pulse_length = np.array([v["pulse_length_table"] for v in config.values()])
-        gain = np.array([v["gain_table"] for v in config.values()])
-        sa_correction = [v["sa_correction_table"] for v in config.values()]
+
         # Save pulse length and sa correction
         ds = xr.Dataset(
             {
                 "frequency_nominal": (
                     ["channel"],
-                    freq,
+                    self.freq,
                     {
                         "units": "Hz",
                         "long_name": "Transducer frequency",
@@ -803,7 +808,11 @@ class SetGroupsEK60(SetGroupsBase):
                 "pulse_length": (["channel", "pulse_length_bin"], pulse_length),
             },
             coords={
-                "channel": (["channel"], channel, self._varattrs["beam_coord_default"]["channel"]),
+                "channel": (
+                    ["channel"],
+                    list(self.sorted_channel.values()),
+                    self._varattrs["beam_coord_default"]["channel"],
+                ),
                 "pulse_length_bin": (
                     ["pulse_length_bin"],
                     np.arange(pulse_length.shape[1]),
