@@ -7,7 +7,6 @@ The code has been modified to handle split-beam data and
 channel-transducer structure from different EK80 setups.
 """
 
-import logging
 import re
 import struct
 import sys
@@ -16,6 +15,7 @@ from collections import Counter
 
 import numpy as np
 
+from ...utils.log import _init_logger
 from .ek_date_conversion import nt_to_unix
 
 TCVR_CH_NUM_MATCHER = re.compile(r"\d{6}-\w{1,2}|\w{12}-\w{1,2}")
@@ -29,7 +29,7 @@ __all__ = [
     "SimradRawParser",
 ]
 
-log = logging.getLogger(__name__)
+logger = _init_logger(__name__)
 
 
 class _SimradDatagramParser(object):
@@ -189,8 +189,8 @@ class SimradDepthParser(_SimradDatagramParser):
 
             if len(set(lengths)) != 1:
                 min_indx = min(lengths)
-                log.warning("Data lengths mismatched:  d:%d, r:%d, u:%d, t:%d", *lengths)
-                log.warning("  Using minimum value:  %d", min_indx)
+                logger.warning("Data lengths mismatched:  d:%d, r:%d, u:%d, t:%d", *lengths)
+                logger.warning("  Using minimum value:  %d", min_indx)
                 data["transceiver_count"] = min_indx
 
             else:
@@ -280,7 +280,7 @@ class SimradBottomParser(_SimradDatagramParser):
         if version == 0:
 
             if len(data["depth"]) != data["transceiver_count"]:
-                log.warning(
+                logger.warning(
                     "# of depth values %d does not match transceiver count %d",
                     len(data["depth"]),
                     data["transceiver_count"],
@@ -1326,12 +1326,12 @@ class SimradConfigParser(_SimradDatagramParser):
                 transducer_header = self._transducer_headers[sounder_name]
                 _sounder_name_used = sounder_name
             except KeyError:
-                log.warning(
+                logger.warning(
                     "Unknown sounder_name:  %s, (no one of %s)",
                     sounder_name,
                     list(self._transducer_headers.keys()),
                 )
-                log.warning("Will use ER60 transducer config fields as default")
+                logger.warning("Will use ER60 transducer config fields as default")
 
                 transducer_header = self._transducer_headers["ER60"]
                 _sounder_name_used = "ER60"
@@ -1403,7 +1403,7 @@ class SimradConfigParser(_SimradDatagramParser):
         if version == 0:
 
             if data["transceiver_count"] != len(data["transceivers"]):
-                log.warning("Mismatch between 'transceiver_count' and actual # of transceivers")
+                logger.warning("Mismatch between 'transceiver_count' and actual # of transceivers")
                 data["transceiver_count"] = len(data["transceivers"])
 
             sounder_name = data["sounder_name"]
@@ -1424,12 +1424,12 @@ class SimradConfigParser(_SimradDatagramParser):
                 transducer_header = self._transducer_headers[sounder_name]
                 _sounder_name_used = sounder_name
             except KeyError:
-                log.warning(
+                logger.warning(
                     "Unknown sounder_name:  %s, (no one of %s)",
                     sounder_name,
                     list(self._transducer_headers.keys()),
                 )
-                log.warning("Will use ER60 transducer config fields as default")
+                logger.warning("Will use ER60 transducer config fields as default")
 
                 transducer_header = self._transducer_headers["ER60"]
                 _sounder_name_used = "ER60"
@@ -1685,19 +1685,19 @@ class SimradRawParser(_SimradDatagramParser):
 
             if data["count"] > 0:
                 if (int(data["mode"]) & 0x1) and (len(data.get("power", [])) != data["count"]):
-                    log.warning(
+                    logger.warning(
                         "Data 'count' = %d, but contains %d power samples.  Ignoring power."
                     )
                     data["mode"] &= ~(1 << 0)
 
                 if (int(data["mode"]) & 0x2) and (len(data.get("angle", [])) != data["count"]):
-                    log.warning(
+                    logger.warning(
                         "Data 'count' = %d, but contains %d angle samples.  Ignoring angle."
                     )
                     data["mode"] &= ~(1 << 1)
 
                 if data["mode"] == 0:
-                    log.warning(
+                    logger.warning(
                         "Data 'count' = %d, but mode == 0.  Setting count to 0",
                         data["count"],
                     )
